==> flutter_dhl_amap-0.0.5.tar.gz: lib/flutter_dhl_amap.dart <==
import 'dart:async';

import 'package:flutter/services.dart';

import 'DHL_Location.dart';
import 'DHL_Location_Model.dart';
import 'Search/DHL_Measure_Model.dart';


class FlutterDhlAmap {
  static const MethodChannel _channel =
      const MethodChannel('flutter_dhl_amap');
  StreamSubscription<dynamic> _streamSubscription;
  StreamSubscription<dynamic> _streamSubscription_Search;

  static StreamController<DHL_Location_Model> _locationUpdateStreamController =
  new StreamController.broadcast();
  /// 定位改变监听
  static Stream<DHL_Location_Model> get onLocationUpate =>
      _locationUpdateStreamController.stream;


  static StreamController<List<DHL_Measure_Model>> _locationUpdateStreamController_Measure =
  new StreamController.broadcast();
  /// 定位改变监听
  static Stream<List<DHL_Measure_Model>> get onLocationUpate_Measure =>
      _locationUpdateStreamController_Measure.stream;



  FlutterDhlAmap(){
    initEvent();
  }
  void initEvent(){
    _streamSubscription = _eventChannelFor().receiveBroadcastStream().listen(eventListener,onError: onerror);
    _streamSubscription_Search = _eventChannelForSearch().receiveBroadcastStream().listen(eventListener_Search,onError: onerror);
  }
  EventChannel _eventChannelForSearch(){
    return EventChannel('flutter_dhl_amap_Search');
  }
  EventChannel _eventChannelFor(){
    return EventChannel('flutter_dhl_amap_location');
  }
  void eventListener_Search(dynamic event){//回调计算数据
    List   map = event;
    List<DHL_Measure_Model> mapList = new List();
    for (Map<dynamic,dynamic> value in map) {
      mapList.add(DHL_Measure_Model.fromMap(value));
    }

    _locationUpdateStreamController_Measure.add(mapList);//返回定位数据
  }
  void eventListener(dynamic event ){
    final Map<dynamic,dynamic> map = event;
    switch(map['event']){
      case 'location':

        _locationUpdateStreamController.add(DHL_Location_Model.fromMap(map));//返回定位数据
        break;

    }
  }
  void onerror(Object object){
    final PlatformException e = object;
    throw e;
  }
  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }
  static void setInit(String key) async {

    await _channel.invokeListMethod('init',key);
  }

  static void startLocation(DHL_AMapLocationOption data) async {//开始定位

    await _channel.invokeListMethod('start_location',data.toMap());

  }

  static Future<Map<dynamic, dynamic>> changeLocation(double slatitude , double slongitude,String type) async {//坐标转换 type: gaode  baidu

    final Map<dynamic, dynamic> map =  await _channel.invokeMethod('zhuan_location',<dynamic, dynamic>{"latitude":slatitude,"longitude":slongitude,"type":type}) ;
    return map;
  }


  static void stopLocation() async {//开始定位

    await _channel.invokeListMethod('stop_location' );

  }

  //type: 0：直线距离; 1：驾车导航距离
  static void Calculation_location (double slatitude , double slongitude,double elatitude , double elongitude,int type) async {//计算距离

    await _channel.invokeListMethod('jisuan_location',{"slatitude":slatitude,"slongitude":slongitude,"elatitude":elatitude,"elongitude":elongitude,"type":type} );

  }

}

==> flutter_dhl_amap-0.0.8.tar.gz: lib/flutter_dhl_amap.dart <==
import 'dart:async';

import 'package:flutter/services.dart';

import 'DHL_Location.dart';
import 'DHL_Location_Model.dart';
import 'Search/DHL_Measure_Model.dart';


class FlutterDhlAmap {
  static const MethodChannel _channel =
      const MethodChannel('flutter_dhl_amap');
  late StreamSubscription<dynamic> _streamSubscription;
  late StreamSubscription<dynamic> _streamSubscription_Search;

  static StreamController<DHL_Location_Model> _locationUpdateStreamController =
  new StreamController.broadcast();
  /// 定位改变监听
  static Stream<DHL_Location_Model> get onLocationUpate =>
      _locationUpdateStreamController.stream;


  static StreamController<List<DHL_Measure_Model>> _locationUpdateStreamController_Measure =
  new StreamController.broadcast();
  /// 定位改变监听
  static Stream<List<DHL_Measure_Model>> get onLocationUpate_Measure =>
      _locationUpdateStreamController_Measure.stream;



  FlutterDhlAmap(){
    initEvent();
  }
  void initEvent(){
    _streamSubscription = _eventChannelFor().receiveBroadcastStream().listen(eventListener,onError: onerror);
    _streamSubscription_Search = _eventChannelForSearch().receiveBroadcastStream().listen(eventListener_Search,onError: onerror);
  }
  EventChannel _eventChannelForSearch(){
    return EventChannel('flutter_dhl_amap_Search');
  }
  EventChannel _eventChannelFor(){
    return EventChannel('flutter_dhl_amap_location');
  }
  void eventListener_Search(dynamic event){//回调计算数据
    List   map = event;
    List<DHL_Measure_Model> mapList = [];
    for (Map<dynamic,dynamic> value in map) {
      mapList.add(DHL_Measure_Model.fromMap(value));
    }

    _locationUpdateStreamController_Measure.add(mapList);//返回定位数据
  }
  void eventListener(dynamic event ){
    final Map<dynamic,dynamic> map = event;
    switch(map['event']){
      case 'location':

        _locationUpdateStreamController.add(DHL_Location_Model.fromMap(map));//返回定位数据
        break;

    }
  }
  void onerror(Object object){
    final Object e = object;
    throw e;
  }
  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }
  static void setInit(String key) async {

    await _channel.invokeListMethod('init',key);
  }

  static void startLocation(DHL_AMapLocationOption data) async {//开始定位

    await _channel.invokeListMethod('start_location',data.toMap());

  }

  static Future<Map<dynamic, dynamic>> changeLocation(double slatitude , double slongitude,String type) async {//坐标转换 type: gaode  baidu

    final Map<dynamic, dynamic> map =  await _channel.invokeMethod('zhuan_location',<dynamic, dynamic>{"latitude":slatitude,"longitude":slongitude,"type":type}) ;
    return map;
  }


  static void stopLocation() async {//开始定位

    await _channel.invokeListMethod('stop_location' );

  }

  //type: 0：直线距离; 1：驾车导航距离
  static void Calculation_location (double slatitude , double slongitude,double elatitude , double elongitude,int type) async {//计算距离

    await _channel.invokeListMethod('jisuan_location',{"slatitude":slatitude,"slongitude":slongitude,"elatitude":elatitude,"elongitude":elongitude,"type":type} );

  }

}
